from distutils.core import setup

setup(name='metadelta',
      version='1.0',
      description='A small library for advanced math.',
      author='Gerald Nash',
      author_email='g.nash.dev@gmail.com',
      url='http://aunyks.com/metadelta',
      keywords= ['cas', 'calculus', 'math', 'symbolic math', 'advanced math'],
)
